@@ -53,9 +53,10 @@ class CountryAdmin(admin.ModelAdmin):
 
 
 class EPNAdmin(admin.ModelAdmin):
-    list_display = ['company', 'cpn', 'epn', 'ipn', 'description']
+    list_display = ['company', 'description', 'epn', 'ipn', 'cpn']
     search_fields = ['company__description', 'cpn__code', 'epn', 'ipn__code'
                      'description']
+    fields = ['company', 'description', 'epn', 'ipn', 'cpn']
 
 
 class IPNAdmin(admin.ModelAdmin):
@@ -69,7 +70,7 @@ class IPNAdmin(admin.ModelAdmin):
 
 
 class PriceGroupAdmin(admin.ModelAdmin):
-    list_display = ['code', 'add', 'rate']
+    list_display = ['code', 'rate', 'add']
 
 
 class PriceMarkerAdmin(admin.ModelAdmin):
